#include "osl/move_generator/open.h"
#include "osl/move_generator/open.tcc"
#include "osl/move_action/store.h"
#include "osl/state/simpleState.h"
#include "osl/state/numEffectState.h"

namespace osl
{
  // explicit template instantiation
  template void move_generator::GenerateOpen::generate
  (Player, const NumEffectState&, Piece, move_action::Store&,
   Square, Direction);

  template void move_generator::Open<move_action::Store>::generate<BLACK>(NumEffectState const&, Piece, move_action::Store&, Square, Direction);
  template void move_generator::Open<move_action::Store>::generate<WHITE>(NumEffectState const&, Piece, move_action::Store&, Square, Direction);
}

// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
